@@ -102,9 +102,10 @@ public:
   	{ return Exec(Query.c_str(), Desc); }
 
   /// Have connection process warning message
-  void ProcessNotice(const char Msg[]) { m_Conn.ProcessNotice(Msg); }	//[t14]
+  void ProcessNotice(const char Msg[]) const 				//[t14]
+  	{ m_Conn.ProcessNotice(Msg); }
   /// Have connection process warning message
-  void ProcessNotice(const PGSTD::string &Msg) 				//[t14]
+  void ProcessNotice(const PGSTD::string &Msg) const			//[t14]
   	{ m_Conn.ProcessNotice(Msg); }
 
   PGSTD::string Name() const { return m_Name; }				//[t1]
@@ -112,6 +113,18 @@ public:
   /// Connection this transaction is running in
   ConnectionItf &Conn() const { return m_Conn; }			//[t4]
 
+  /// Set session variable in this connection
+  /** The new value is typically forgotten if the transaction aborts.  
+   * Known exceptions to this rule are NonTransaction, and PostgreSQL versions
+   * prior to 7.3.  In the case of NonTransaction, the set value will be kept
+   * regardless, but if the connection ever needs to be recovered, the set value
+   * will not be restored.
+   * @param Var the variable to set
+   * @param Value the value to store in the variable
+   */
+  void SetVariable(const PGSTD::string &Var, const PGSTD::string &Value);//[]
+
+
 protected:
   /// Create a transaction.  The optional name, if given, must begin with a
   /// letter and may contain letters and digits only.
@@ -169,8 +182,8 @@ private:
   void MakeEmpty(Result &R) const { m_Conn.MakeEmpty(R); }
 
   friend class TableStream;
-  void RegisterStream(const TableStream *);
-  void UnregisterStream(const TableStream *) throw ();
+  void RegisterStream(TableStream *);
+  void UnregisterStream(TableStream *) throw ();
   void EndCopy() { m_Conn.EndCopy(); }
   friend class TableReader;
   void BeginCopyRead(const PGSTD::string &Table) 
@@ -188,6 +201,7 @@ private:
   Unique<TableStream> m_Stream;
   Status m_Status;
   bool m_Registered;
+  mutable PGSTD::map<PGSTD::string, PGSTD::string> m_Vars;
 
   // Not allowed:
   TransactionItf();
