@@ -229,6 +229,80 @@ template<typename T> inline PGSTD::string Quote(const T &Obj, bool EmptyIsNull)
 template<typename T> PGSTD::string Classname(const T *);
 
 
+/// Keep track of a libpq-allocated pointer to be free()d automatically.
+/** Ownership policy is simple: object dies when PQAlloc object's value does.
+ * If the available PostgreSQL development files supply PQfreemem(), this is
+ * used to free the memory.  If not, free() is used instead.  This matters on
+ * Windows, where memory allocated by a DLL must be freed by the same DLL.
+ */
+template<typename T> class PQAlloc
+{
+  T *m_Obj;
+public:
+  PQAlloc() : m_Obj(0) {}
+
+  /// Assume ownership of a pointer
+  explicit PQAlloc(T *obj) : m_Obj(obj) {}
+
+  ~PQAlloc() { close(); }
+
+  /// Assume ownership of a pointer, freeing the previous one (if any)
+  /** If the new and the old pointer are identical, no action is performed.
+   */
+  PQAlloc &operator=(T *obj) throw ()
+  { 
+    if (obj != m_Obj)
+    {
+      close();
+      m_Obj = obj;
+    }
+    return *this;
+  }
+
+  /// Is this pointer non-null?
+  operator bool() const throw () { return m_Obj != 0; }
+
+  /// Is this pointer null?
+  bool operator!() const throw () { return !m_Obj; }
+
+  /// Dereference pointer
+  /** Throws a logic_error if the pointer is null.
+   */
+  T *operator->() const throw (PGSTD::logic_error)
+  {
+    if (!m_Obj) throw PGSTD::logic_error("Null pointer dereferenced");
+    return m_Obj;
+  }
+
+  /// Dereference pointer
+  /** Throws a logic_error if the pointer is null.
+   */
+  T &operator*() const throw (PGSTD::logic_error) { return *operator->(); }
+
+  /// Obtain underlying pointer
+  /** Ownership of the pointer's memory remains with the PQAlloc object
+   */
+  T *c_ptr() const throw () { return m_Obj; }
+
+  /// Free and reset current pointer (if any)
+  void close() throw () { if (m_Obj) freemem(); m_Obj = 0; }
+
+private:
+  void freemem() throw ()
+  {
+#ifdef HAVE_PQFREEMEM
+    PQfreemem(m_Obj);
+#else
+    free(m_Obj);
+#endif
+  }
+
+  PQAlloc(const PQAlloc &);		// Not allowed
+  PQAlloc &operator=(const PQAlloc &);	// Not allowed
+};
+
+
+
 /// Ensure proper opening/closing of GUEST objects related to a "host" object,
 /// where only a single GUEST may exist for a single host at any given time.
 /// The template assumes that Classname<GUEST>() returns a user-readable name
@@ -240,9 +314,9 @@ class Unique
 public:
   Unique() : m_Guest(0) {}
 
-  const GUEST *get() const throw () { return m_Guest; }
+  GUEST *get() const throw () { return m_Guest; }
 
-  void Register(const GUEST *G)
+  void Register(GUEST *G)
   {
     if (!G) throw PGSTD::logic_error("Internal libpqxx error: NULL " + 
 		                     Classname(G));
@@ -267,7 +341,7 @@ public:
     m_Guest = G;
   }
 
-  void Unregister(const GUEST *G)
+  void Unregister(GUEST *G)
   {
     if (G != m_Guest)
     {
@@ -293,7 +367,7 @@ public:
   }
 
 private:
-  const GUEST *m_Guest;
+  GUEST *m_Guest;
 
   // Not allowed:
   Unique(const Unique &);
