@@ -23,59 +23,6 @@
 
 using namespace PGSTD;
 
-namespace
-{
-
-// Keep track of a pointer to be free()d automatically.
-// Ownership policy is simple: object dies when PQAlloc object's value does.
-template<typename T> class PQAlloc
-{
-  T *m_Obj;
-public:
-  PQAlloc() : m_Obj(0) {}
-  explicit PQAlloc(T *obj) : m_Obj(obj) {}
-  ~PQAlloc() { close(); }
-
-  PQAlloc &operator=(T *obj) throw ()
-  { 
-    if (obj != m_Obj)
-    {
-      close();
-      m_Obj = obj;
-    }
-    return *this;
-  }
-
-  operator bool() const throw () { return m_Obj != 0; }
-  bool operator!() const throw () { return !m_Obj; }
-
-  T *operator->() const
-  {
-    if (!m_Obj) throw logic_error("Null pointer dereferenced");
-    return m_Obj;
-  }
-
-  T &operator*() const { return *operator->(); }
-
-  T *c_ptr() const throw () { return m_Obj; }
-
-  void close() throw () { if (m_Obj) freemem(); m_Obj = 0; }
-
-  void freemem() throw ()
-  {
-#ifdef HAVE_PQFREEMEM
-    PQfreemem(m_Obj);
-#else
-    free(m_Obj);
-#endif
-  }
-
-private:
-  PQAlloc(const PQAlloc &);		// Not allowed
-  PQAlloc &operator=(const PQAlloc &);	// Not allowed
-};
-} // namespace
-
 
 extern "C"
 {
@@ -108,7 +55,7 @@ pqxx::ConnectionItf::ConnectionItf(const char ConnInfo[]) :
 }
 
 
-void pqxx::ConnectionItf::Connect() const
+void pqxx::ConnectionItf::Connect()
 {
   if (m_Conn) throw logic_error("libqxx internal error: spurious Connect()");
 
@@ -136,7 +83,7 @@ void pqxx::ConnectionItf::Connect() const
 
 
 
-void pqxx::ConnectionItf::Deactivate() const
+void pqxx::ConnectionItf::Deactivate()
 {
   if (m_Conn)
   {
@@ -150,11 +97,18 @@ void pqxx::ConnectionItf::Deactivate() const
 }
 
 
-// TODO: Restore encoding when restoring connection!
-void pqxx::ConnectionItf::SetClientEncoding(const char Encoding[])
+void pqxx::ConnectionItf::SetVariable(const PGSTD::string &Var,
+                                      const PGSTD::string &Value)
 {
-  if (PQsetClientEncoding(m_Conn, Encoding) != 0)
-    throw runtime_error(ErrMsg());
+  if (m_Trans.get())
+  {
+    m_Trans.get()->SetVariable(Var, Value);
+  }
+  else
+  {
+    RawSetVar(Var, Value);
+    m_Vars[Var] = Value;
+  }
 }
 
 
@@ -162,7 +116,7 @@ void pqxx::ConnectionItf::SetClientEncoding(const char Encoding[])
  * recovered because the physical connection to the database was lost and is
  * being reset, or that may not have been initialized yet.
  */
-void pqxx::ConnectionItf::SetupState() const
+void pqxx::ConnectionItf::SetupState()
 {
   if (!m_Conn) 
     throw logic_error("libpqxx internal error: SetupState() on no connection");
@@ -190,10 +144,15 @@ void pqxx::ConnectionItf::SetupState() const
       }
     }
   }
+
+  for (map<string,string>::const_iterator i=m_Vars.begin(); 
+       i!=m_Vars.end(); 
+       ++i)
+    RawSetVar(i->first, i->second);
 }
 
 
-void pqxx::ConnectionItf::Disconnect() const throw ()
+void pqxx::ConnectionItf::Disconnect() throw ()
 {
   if (m_Conn)
   {
@@ -428,9 +387,21 @@ void pqxx::ConnectionItf::close() throw ()
 }
 
 
+void pqxx::ConnectionItf::RawSetVar(const string &Var, const string &Value)
+{
+    Activate();
+    Exec(("SET " + Var + "=" + Value).c_str(), 0);
+}
 
 
-void pqxx::ConnectionItf::InternalSetTrace() const
+void pqxx::ConnectionItf::AddVariables(const map<string,string> &Vars)
+{
+  for (map<string,string>::const_iterator i=Vars.begin(); i!=Vars.end(); ++i)
+    m_Vars[i->first] = i->second;
+}
+
+
+void pqxx::ConnectionItf::InternalSetTrace()
 {
   if (m_Trace) PQtrace(m_Conn, m_Trace);
   else PQuntrace(m_Conn);
@@ -438,13 +409,14 @@ void pqxx::ConnectionItf::InternalSetTrace() const
 
 
 
-void pqxx::ConnectionItf::RegisterTransaction(const TransactionItf *T)
+void pqxx::ConnectionItf::RegisterTransaction(TransactionItf *T)
 {
   m_Trans.Register(T);
 }
 
 
-void pqxx::ConnectionItf::UnregisterTransaction(const TransactionItf *T) throw ()
+void pqxx::ConnectionItf::UnregisterTransaction(TransactionItf *T) 
+  throw ()
 {
   try
   {
