@@ -112,6 +112,8 @@ void pqxx::TransactionItf::Commit()
     throw;
   }
 
+  m_Conn.AddVariables(m_Vars);
+
   End();
 }
 
@@ -202,6 +204,13 @@ pqxx::Result pqxx::TransactionItf::Exec(const char Query[],
 }
 
 
+void pqxx::TransactionItf::SetVariable(const PGSTD::string &Var,
+                                       const PGSTD::string &Value)
+{
+  m_Conn.RawSetVar(Var, Value);
+  m_Vars[Var] = Value;
+}
+
 
 void pqxx::TransactionItf::Begin()
 {
@@ -252,13 +261,13 @@ void pqxx::TransactionItf::End() throw ()
 
 
 
-void pqxx::TransactionItf::RegisterStream(const TableStream *S)
+void pqxx::TransactionItf::RegisterStream(TableStream *S)
 {
   m_Stream.Register(S);
 }
 
 
-void pqxx::TransactionItf::UnregisterStream(const TableStream *S) throw ()
+void pqxx::TransactionItf::UnregisterStream(TableStream *S) throw ()
 {
   try
   {
