@@ -138,6 +138,14 @@ int main(int, char *argv[])
       throw logic_error("First row was '" + Row + "' going forward, "
 		        "but '" + R[0][0].c_str() + "' going back!");
   }
+  catch (const sql_error &e)
+  {
+    // If we're interested in the text of a failed query, we can write separate
+    // exception handling code for this type of exception
+    cerr << "SQL error: " << e.what() << endl
+         << "Query was: '" << e.query() << "'" << endl;
+    return 1;
+  }
   catch (const exception &e)
   {
     // All exceptions thrown by libpqxx are derived from std::exception
